@@ -19,26 +19,28 @@
 
 model.appr <- function(current.parms, critical.parms, do.not.fit = NULL){
   if(is.null(do.not.fit) == FALSE){
-    if(sum(is.element(do.not.fit, current.parms))> 0){
-      return(FALSE)
+    for(i in 1:length(do.not.fit)){
+      if(is.element(do.not.fit[i], current.parms)){
+        return(FALSE)
+      }
     }
-  }
+  } 
   if(length(critical.parms) == 0){
     return(TRUE)
   }
-  model.valid <- TRUE
+
   #cycle through all the list entries
   for(i in 1:length(critical.parms)){
-    #get list entry
-    test.set <- critical.parms[[i]]
-    #test if intersection is empty
-    if(length(intersect(current.parms, test.set)) == 0){
-      #print(i)
-      model.valid <- FALSE
-      return(FALSE)
+    iterx = critical.parms[[i]]
+    for(j in 1:length(iterx)){
+      if(is.element(iterx[j], current.parms)){
+        break
+      }else if(j == length(iterx)){
+        return(FALSE)
+      }
     }
   }
   #return if model is valid or not
-  return(model.valid)
+  return(TRUE)
   
 }
